==> nats.c_3.7.0.orig.tar.gz: nats.c-3.7.0/doc/html/annotated_dup.js <==
var annotated_dup =
[
    [ "jsAccountInfo", "structjs_account_info.html", "structjs_account_info" ],
    [ "jsAccountLimits", "structjs_account_limits.html", "structjs_account_limits" ],
    [ "jsAPIStats", "structjs_a_p_i_stats.html", "structjs_a_p_i_stats" ],
    [ "jsClusterInfo", "structjs_cluster_info.html", "structjs_cluster_info" ],
    [ "jsConsumerConfig", "structjs_consumer_config.html", "structjs_consumer_config" ],
    [ "jsConsumerInfo", "structjs_consumer_info.html", "structjs_consumer_info" ],
    [ "jsConsumerInfoList", "structjs_consumer_info_list.html", "structjs_consumer_info_list" ],
    [ "jsConsumerNamesList", "structjs_consumer_names_list.html", "structjs_consumer_names_list" ],
    [ "jsConsumerSequenceMismatch", "structjs_consumer_sequence_mismatch.html", "structjs_consumer_sequence_mismatch" ],
    [ "jsDirectGetMsgOptions", "structjs_direct_get_msg_options.html", "structjs_direct_get_msg_options" ],
    [ "jsExternalStream", "structjs_external_stream.html", "structjs_external_stream" ],
    [ "jsFetchRequest", "structjs_fetch_request.html", "structjs_fetch_request" ],
    [ "jsLostStreamData", "structjs_lost_stream_data.html", "structjs_lost_stream_data" ],
    [ "jsMsgMetaData", "structjs_msg_meta_data.html", "structjs_msg_meta_data" ],
    [ "jsOptions", "structjs_options.html", "structjs_options" ],
    [ "jsPeerInfo", "structjs_peer_info.html", "structjs_peer_info" ],
    [ "jsPlacement", "structjs_placement.html", "structjs_placement" ],
    [ "jsPubAck", "structjs_pub_ack.html", "structjs_pub_ack" ],
    [ "jsPubAckErr", "structjs_pub_ack_err.html", "structjs_pub_ack_err" ],
    [ "jsPubOptions", "structjs_pub_options.html", "structjs_pub_options" ],
    [ "jsRePublish", "structjs_re_publish.html", "structjs_re_publish" ],
    [ "jsSequenceInfo", "structjs_sequence_info.html", "structjs_sequence_info" ],
    [ "jsSequencePair", "structjs_sequence_pair.html", "structjs_sequence_pair" ],
    [ "jsStreamAlternate", "structjs_stream_alternate.html", "structjs_stream_alternate" ],
    [ "jsStreamConfig", "structjs_stream_config.html", "structjs_stream_config" ],
    [ "jsStreamConsumerLimits", "structjs_stream_consumer_limits.html", "structjs_stream_consumer_limits" ],
    [ "jsStreamInfo", "structjs_stream_info.html", "structjs_stream_info" ],
    [ "jsStreamInfoList", "structjs_stream_info_list.html", "structjs_stream_info_list" ],
    [ "jsStreamNamesList", "structjs_stream_names_list.html", "structjs_stream_names_list" ],
    [ "jsStreamSource", "structjs_stream_source.html", "structjs_stream_source" ],
    [ "jsStreamSourceInfo", "structjs_stream_source_info.html", "structjs_stream_source_info" ],
    [ "jsStreamState", "structjs_stream_state.html", "structjs_stream_state" ],
    [ "jsStreamStateSubject", "structjs_stream_state_subject.html", "structjs_stream_state_subject" ],
    [ "jsStreamStateSubjects", "structjs_stream_state_subjects.html", "structjs_stream_state_subjects" ],
    [ "jsSubjectTransformConfig", "structjs_subject_transform_config.html", "structjs_subject_transform_config" ],
    [ "jsSubOptions", "structjs_sub_options.html", "structjs_sub_options" ],
    [ "jsTier", "structjs_tier.html", "structjs_tier" ],
    [ "kvConfig", "structkv_config.html", "structkv_config" ],
    [ "kvEntryList", "structkv_entry_list.html", "structkv_entry_list" ],
    [ "kvKeysList", "structkv_keys_list.html", "structkv_keys_list" ],
    [ "kvPurgeOptions", "structkv_purge_options.html", "structkv_purge_options" ],
    [ "kvWatchOptions", "structkv_watch_options.html", "structkv_watch_options" ],
    [ "micro_endpoint_config_s", "structmicro__endpoint__config__s.html", "structmicro__endpoint__config__s" ],
    [ "micro_endpoint_info_s", "structmicro__endpoint__info__s.html", "structmicro__endpoint__info__s" ],
    [ "micro_endpoint_stats_s", "structmicro__endpoint__stats__s.html", "structmicro__endpoint__stats__s" ],
    [ "micro_service_config_s", "structmicro__service__config__s.html", "structmicro__service__config__s" ],
    [ "micro_service_info_s", "structmicro__service__info__s.html", "structmicro__service__info__s" ],
    [ "micro_service_stats_s", "structmicro__service__stats__s.html", "structmicro__service__stats__s" ],
    [ "natsMetadata", "structnats_metadata.html", "structnats_metadata" ],
    [ "natsMsgList", "structnats_msg_list.html", "structnats_msg_list" ]
];

==> nats.c_3.9.2.orig.tar.gz: nats.c-3.9.2/doc/html/annotated_dup.js <==
var annotated_dup =
[
    [ "__natsClientConfig", "struct____nats_client_config.html", "struct____nats_client_config" ],
    [ "jsAccountInfo", "structjs_account_info.html", "structjs_account_info" ],
    [ "jsAccountLimits", "structjs_account_limits.html", "structjs_account_limits" ],
    [ "jsAPIStats", "structjs_a_p_i_stats.html", "structjs_a_p_i_stats" ],
    [ "jsClusterInfo", "structjs_cluster_info.html", "structjs_cluster_info" ],
    [ "jsConsumerConfig", "structjs_consumer_config.html", "structjs_consumer_config" ],
    [ "jsConsumerInfo", "structjs_consumer_info.html", "structjs_consumer_info" ],
    [ "jsConsumerInfoList", "structjs_consumer_info_list.html", "structjs_consumer_info_list" ],
    [ "jsConsumerNamesList", "structjs_consumer_names_list.html", "structjs_consumer_names_list" ],
    [ "jsConsumerPauseResponse", "structjs_consumer_pause_response.html", "structjs_consumer_pause_response" ],
    [ "jsConsumerSequenceMismatch", "structjs_consumer_sequence_mismatch.html", "structjs_consumer_sequence_mismatch" ],
    [ "jsDirectGetMsgOptions", "structjs_direct_get_msg_options.html", "structjs_direct_get_msg_options" ],
    [ "jsExternalStream", "structjs_external_stream.html", "structjs_external_stream" ],
    [ "jsFetchRequest", "structjs_fetch_request.html", "structjs_fetch_request" ],
    [ "jsLostStreamData", "structjs_lost_stream_data.html", "structjs_lost_stream_data" ],
    [ "jsMsgMetaData", "structjs_msg_meta_data.html", "structjs_msg_meta_data" ],
    [ "jsOptions", "structjs_options.html", "structjs_options" ],
    [ "jsPeerInfo", "structjs_peer_info.html", "structjs_peer_info" ],
    [ "jsPlacement", "structjs_placement.html", "structjs_placement" ],
    [ "jsPubAck", "structjs_pub_ack.html", "structjs_pub_ack" ],
    [ "jsPubAckErr", "structjs_pub_ack_err.html", "structjs_pub_ack_err" ],
    [ "jsPubOptions", "structjs_pub_options.html", "structjs_pub_options" ],
    [ "jsRePublish", "structjs_re_publish.html", "structjs_re_publish" ],
    [ "jsSequenceInfo", "structjs_sequence_info.html", "structjs_sequence_info" ],
    [ "jsSequencePair", "structjs_sequence_pair.html", "structjs_sequence_pair" ],
    [ "jsStreamAlternate", "structjs_stream_alternate.html", "structjs_stream_alternate" ],
    [ "jsStreamConfig", "structjs_stream_config.html", "structjs_stream_config" ],
    [ "jsStreamConsumerLimits", "structjs_stream_consumer_limits.html", "structjs_stream_consumer_limits" ],
    [ "jsStreamInfo", "structjs_stream_info.html", "structjs_stream_info" ],
    [ "jsStreamInfoList", "structjs_stream_info_list.html", "structjs_stream_info_list" ],
    [ "jsStreamNamesList", "structjs_stream_names_list.html", "structjs_stream_names_list" ],
    [ "jsStreamSource", "structjs_stream_source.html", "structjs_stream_source" ],
    [ "jsStreamSourceInfo", "structjs_stream_source_info.html", "structjs_stream_source_info" ],
    [ "jsStreamState", "structjs_stream_state.html", "structjs_stream_state" ],
    [ "jsStreamStateSubject", "structjs_stream_state_subject.html", "structjs_stream_state_subject" ],
    [ "jsStreamStateSubjects", "structjs_stream_state_subjects.html", "structjs_stream_state_subjects" ],
    [ "jsSubjectTransformConfig", "structjs_subject_transform_config.html", "structjs_subject_transform_config" ],
    [ "jsSubOptions", "structjs_sub_options.html", "structjs_sub_options" ],
    [ "jsTier", "structjs_tier.html", "structjs_tier" ],
    [ "kvConfig", "structkv_config.html", "structkv_config" ],
    [ "kvEntryList", "structkv_entry_list.html", "structkv_entry_list" ],
    [ "kvKeysList", "structkv_keys_list.html", "structkv_keys_list" ],
    [ "kvPurgeOptions", "structkv_purge_options.html", "structkv_purge_options" ],
    [ "kvWatchOptions", "structkv_watch_options.html", "structkv_watch_options" ],
    [ "micro_endpoint_config_s", "structmicro__endpoint__config__s.html", "structmicro__endpoint__config__s" ],
    [ "micro_endpoint_info_s", "structmicro__endpoint__info__s.html", "structmicro__endpoint__info__s" ],
    [ "micro_endpoint_stats_s", "structmicro__endpoint__stats__s.html", "structmicro__endpoint__stats__s" ],
    [ "micro_group_config_s", "structmicro__group__config__s.html", "structmicro__group__config__s" ],
    [ "micro_service_config_s", "structmicro__service__config__s.html", "structmicro__service__config__s" ],
    [ "micro_service_info_s", "structmicro__service__info__s.html", "structmicro__service__info__s" ],
    [ "micro_service_stats_s", "structmicro__service__stats__s.html", "structmicro__service__stats__s" ],
    [ "natsMetadata", "structnats_metadata.html", "structnats_metadata" ],
    [ "natsMsgList", "structnats_msg_list.html", "structnats_msg_list" ]
];
